@@ -12,7 +12,7 @@
 //! # Example
 //!
 //! ```no_run
-//! use poem::{handler, listener::TcpListener, route, web::Path, Server};
+//! use poem::{handler, listener::TcpListener, route, route::get, web::Path, Server};
 //!
 //! #[handler]
 //! fn hello(Path(name): Path<String>) -> String {
@@ -20,12 +20,11 @@
 //! }
 //!
 //! #[tokio::main]
-//! async fn main() {
-//!     use poem::route::get;
+//! async fn main() -> Result<(), std::io::Error> {
 //!     let app = route().at("/hello/:name", get(hello));
 //!     let listener = TcpListener::bind("127.0.0.1:3000");
-//!     let server = Server::new(listener).await.unwrap();
-//!     server.run(app).await.unwrap();
+//!     let server = Server::new(listener).await?;
+//!     server.run(app).await
 //! }
 //! ```
 //!
@@ -64,7 +63,6 @@ pub use http;
 mod body;
 mod request;
 mod response;
-mod route_recognizer;
 mod server;
 
 pub use async_trait::async_trait;
